@@ -254,6 +254,44 @@ example above.
 Note that mapping to a directory path, instead of a drive letter,
 does not suffer from the same limitations.
 
+### Mounting on macOS
+
+Mounting on macOS can be done either via [macFUSE](https://osxfuse.github.io/) 
+(also known as osxfuse) or [FUSE-T](https://www.fuse-t.org/). macFUSE is a traditional
+FUSE driver utilizing a macOS kernel extension (kext). FUSE-T is an alternative FUSE system
+which "mounts" via an NFSv4 local server.
+
+#### FUSE-T Limitations, Caveats, and Notes
+
+There are some limitations, caveats, and notes about how it works. These are current as 
+of FUSE-T version 1.0.14.
+
+##### ModTime update on read
+
+As per the [FUSE-T wiki](https://github.com/macos-fuse-t/fuse-t/wiki#caveats):
+
+> File access and modification times cannot be set separately as it seems to be an 
+> issue with the NFS client which always modifies both. Can be reproduced with 
+> 'touch -m' and 'touch -a' commands
+
+This means that viewing files with various tools, notably macOS Finder, will cause rlcone
+to update the modification time of the file. This may make rclone upload a full new copy
+of the file.
+
+##### Unicode Normalization
+
+Rclone includes flags for unicode normalization with macFUSE that should be updated
+for FUSE-T. See [this forum post](https://forum.rclone.org/t/some-unicode-forms-break-mount-on-macos-with-fuse-t/36403)
+and [FUSE-T issue #16](https://github.com/macos-fuse-t/fuse-t/issues/16). The following
+flag should be added to the |rclone mount| command.
+
+    -o modules=iconv,from_code=UTF-8,to_code=UTF-8
+    
+##### Read Only mounts
+
+When mounting with |--read-only|, attempts to write to files will fail *silently* as
+opposed to with a clear warning as in macFUSE.
+
 ### Limitations
 
 Without the use of |--vfs-cache-mode| this can only write files
